aboutsummaryrefslogtreecommitdiff
path: root/configs
diff options
context:
space:
mode:
authorKevin Peng <kevin.peng@arm.com>2020-03-04 16:55:37 +0800
committerKevin Peng <kevin.peng@arm.com>2020-06-12 13:28:21 +0800
commitc6d7450aa7bdffd92c28555808083d9e06f72efe (patch)
tree0ba01437c298e54d52b7f9b89c79e43cd95010af /configs
parent894e642e20ed371a088e7e6d59205e85e826ed35 (diff)
downloadtrusted-firmware-m-c6d7450aa7bdffd92c28555808083d9e06f72efe.tar.gz
SST: Rename SST(Secure STorage) to PS(Protected Storage)
This patches renames SST(Secure STorage) to PS(Protected Storage) for files, folders and any contents in files to align with the PSA Storage API spec. Change-Id: Icf991f59512875780c159f22737b521b3b2d4924 Signed-off-by: Kevin Peng <kevin.peng@arm.com>
Diffstat (limited to 'configs')
-rw-r--r--configs/ConfigDefaultProfileS.cmake4
-rw-r--r--configs/ConfigRegressionProfileS.cmake4
2 files changed, 4 insertions, 4 deletions
diff --git a/configs/ConfigDefaultProfileS.cmake b/configs/ConfigDefaultProfileS.cmake
index b52a11ebe0..aa54ead862 100644
--- a/configs/ConfigDefaultProfileS.cmake
+++ b/configs/ConfigDefaultProfileS.cmake
@@ -60,8 +60,8 @@ set(TFM_PARTITION_AUDIT_LOG OFF)
# Disable Platform service
set(TFM_PARTITION_PLATFORM OFF)
-# Disable Secure Storage service
-set(TFM_PARTITION_SECURE_STORAGE OFF)
+# Disable Protected Storage service
+set(TFM_PARTITION_PROTECTED_STORAGE OFF)
# Disable Initial Attestation service temporarily
set(TFM_PARTITION_INITIAL_ATTESTATION OFF)
diff --git a/configs/ConfigRegressionProfileS.cmake b/configs/ConfigRegressionProfileS.cmake
index 2d1b7792ff..324ebb22d9 100644
--- a/configs/ConfigRegressionProfileS.cmake
+++ b/configs/ConfigRegressionProfileS.cmake
@@ -63,8 +63,8 @@ set(TFM_PARTITION_AUDIT_LOG OFF)
# Disable Platform service
set(TFM_PARTITION_PLATFORM OFF)
-# Disable Secure Storage service
-set(TFM_PARTITION_SECURE_STORAGE OFF)
+# Disable Protected Storage service
+set(TFM_PARTITION_PROTECTED_STORAGE OFF)
# Disable Initial Attestation service temporarily
set(TFM_PARTITION_INITIAL_ATTESTATION OFF)